.. include:: references.rst

====================================
Fetch API documentation
====================================

.. py:module:: Ska.engarchive.fetch

Classes
--------
.. autoclass:: MSID
   :show-inheritance:
   :members:

.. autoclass:: MSIDset
   :show-inheritance:
   :members:

.. autoclass:: Msid
   :show-inheritance:
   :members:

.. autoclass:: Msidset
   :show-inheritance:
   :members:

Functions
-----------
.. autofunction:: get_telem

.. autofunction:: get_time_range

.. autofunction:: get_units

.. autofunction:: msid_glob

.. autofunction:: read_bad_times

.. autofunction:: set_units

Time and Date formats
----------------------
.. include:: date_time_formats.rst

